<?php
/**
 * Define settings used throughout the plugin.
 *
 * @package   Good Reviews for WordPress
 * @copyright Copyright (c) 2016, Theme of the Crop
 * @license   GPL-2.0+
 * @since     2.0.0
 */

defined( 'ABSPATH' ) || exit;

if ( ! class_exists( 'grfwpSettings' ) ) :

	/**
	 * Class to handle configurable settings for Good Reviews
	 *
	 * @since 2.0.0
	 */
	class grfwpSettings {

		/**
		 * Default values for settings
		 *
		 * @since  2.0.0
		 * @access public
		 * @var    array
		 */
		public $defaults = array();

		/**
		 * Stored values for settings
		 *
		 * @since  2.0.0
		 * @access public
		 * @var    array
		 */
		public $settings = array();

		/**
		 * Initialize the class and register hooks.
		 *
		 * @since  2.0.0
		 * @access public
		 * @return void
		 */
		public function __construct() {

			add_action( 'init', array( $this, 'set_defaults' ) );

			add_action( 'init', array( $this, 'load_settings_panel' ) );
		}

		/**
		 * Load the plugin's default settings
		 *
		 * @since  2.0.0
		 * @access public
		 * @return void
		 */
		public function set_defaults() {

			$this->defaults = array(
				'grfwp-date-format' 		=> get_option( 'date_format' ) . ' ' . get_option( 'time_format' ),
				'grfwp-reviews-per-page'	=> 10,
			);

			$this->defaults = apply_filters( 'grfwp_defaults', $this->defaults );
		}

		/**
		 * Get a setting's value or fallback to a default if one exists
		 *
		 * @since  2.0.0
		 * @access public
		 * @param  string $setting The setting to retrieve.
		 * @param  string $location The location where the setting is used.
		 * @return mixed A setting based on the key provided.
		 */
		public function get_setting( $setting, $location = false ) {

			if ( empty( $this->settings ) ) {
				$this->settings = get_option( 'grfwp-settings' );
			}

			if ( ! empty( $this->settings[ $setting ] ) ) {
				return $this->settings[ $setting ];
			}

			if ( ! empty( $this->defaults[ $setting ] ) ) {
				return $this->defaults[ $setting ];
			}

			return null;
		}

		/**
		 * Set a setting to a particular value
		 * @since 2.0.3
		 */
		public function set_setting( $setting, $value ) {

			if ( empty( $this->settings ) ) {
				$this->settings = get_option( 'grfwp-settings' );
			}

			if ( $setting_name ) {
				$this->settings[ $setting_name ] = $setting_value;
			}
		}

		/**
		 * Save all of the settings
		 * @since 2.0.3
		 */
		public function save_settings() {
		
			update_option( 'grfwp-settings', $this->settings );
		}

		/**
		 * Load the admin settings page.
		 *
		 * @since 0.0.1
		 * @access public
		 * @link  https://github.com/NateWr/simple-admin-pages
		 */
		public function load_settings_panel() {

			global $grfwp_controller;

			require_once GRFWP_PLUGIN_DIR . '/lib/simple-admin-pages/simple-admin-pages.php';
			$sap = sap_initialize_library(
				$args = array(
					'version' 	=> '2.6.1',
					'lib_url' 	=> GRFWP_PLUGIN_URL . '/lib/simple-admin-pages/',
					'theme'		=> 'blue',
				)
			);

			$sap->add_page(
				'submenu',
				array(
					'id'            => 'grfwp-settings',
					'parent_menu'	=> 'grfwp-restaurant-reviews',
					'title'         => __( 'Settings', 'good-reviews-wp' ),
					'menu_title'    => __( 'Settings', 'good-reviews-wp' ),
					'capability'    => 'manage_options',
					'default_tab'   => 'grfwp-basic',
				)
			);

			$sap->add_section(
				'grfwp-settings',
				array(
					'id'            => 'grfwp-basic',
					'title'         => __( 'Basic', 'good-reviews-wp' ),
					'is_tab'		=> true,
				)
			);

			$sap->add_section(
				'grfwp-settings',
				array(
					'id'    => 'grfwp-basic-general',
					'title' => __( 'General', 'good-reviews-wp' ),
					'tab'	=> 'grfwp-basic'
				)
			);

			$sap->add_setting(
				'grfwp-settings',
				'grfwp-basic-general',
				'number',
				array(
					'id'			=> 'grfwp-reviews-per-page',
					'title'			=> __( 'Reviews per Page', 'good-reviews-wp' ),
					'description'	=> __( 'How many reviews should be displayed when using the shortcode? Default is 10 and additional reviews can be viewed by clicking on the "Show More" button.', 'good-reviews-wp' )
				)
			);

//			$sap->add_setting(
//				'grfwp-settings',
//				'grfwp-basic-general',
//				'number',
//				array(
//					'id'			=> 'grfwp-max-characters',
//					'title'			=> __( 'Max Characters', 'good-reviews-wp' ),
//					'description'	=> __( 'Set a maximum number of characters to display for each review.', 'good-reviews-wp' )
//				)
//			);
//
//			$sap->add_setting(
//				'grfwp-settings',
//				'grfwp-basic-general',
//				'toggle',
//				array(
//					'id'			=> 'grfwp-read-more-permalink',
//					'title'			=> __( 'Read More Permalink Page', 'good-reviews-wp' ),
//					'description'	=> __( 'Enabling this option will make it so that the "Read More" button displays on every review and links to the permalink page instead of the provided custom URL.', 'good-reviews-wp' ),
//				)
//			);
//
//			$sap->add_setting(
//				'grfwp-settings',
//				'grfwp-basic-general',
//				'toggle',
//				array(
//					'id'			=> 'grfwp-read-more-pop-up',
//					'title'			=> __( 'Read More Pop-Up', 'good-reviews-wp' ),
//					'description'	=> __( 'Enabling this option will make it so that the "Read More" button opens up a pop-up window/lightbox, with the full review content, instead of linking to the permalink page or the provided custom URL.', 'good-reviews-wp' ),
//				)
//			);

			$sap->add_setting(
				'grfwp-settings',
				'grfwp-basic-general',
				'toggle',
				array(
					'id'			=> 'grfwp-enable-datepicker',
					'title'			=> __( 'Enable Datepicker?', 'good-reviews-wp' ),
					'description'	=> __( 'Enable a datepicker for the "Review Date" field on the review create/edit screen (instead of the default text input)?', 'good-reviews-wp' ),
				)
			);

			$sap->add_setting(
				'grfwp-settings',
				'grfwp-basic-general',
				'select',
				array(
					'id'			=> 'grfwp-date-format',
					'title'			=> __( 'Date Format', 'good-reviews-wp' ),
					'description'	=> __( 'Choose the format for the datepicker, if enabled in the setting above.', 'good-reviews-wp' ),
					'blank_option' => false,
					'options'      => array(
						'yy-mm-dd'		=> 'yy-mm-dd',
						'dd-mm-yy'		=> 'dd-mm-yy',
						'mm-dd-yy'		=> 'mm-dd-yy',
						'dd/mm/yy'		=> 'dd/mm/yy',
						'mm/dd/yy'		=> 'mm/dd/yy'
					),
					'conditional_on'		=> 'grfwp-enable-datepicker',
					'conditional_on_value'	=> true,
				)
			);

			$sap->add_section(
				'grfwp-settings',
				array(
					'id'    => 'grfwp-integrations',
					'title' => __( 'Plugin Integrations', 'good-reviews-wp' ),
					'tab'	=> 'grfwp-basic'
				)
			);

			$sap->add_setting(
				'grfwp-settings',
				'grfwp-integrations',
				'toggle',
				array(
					'id'			=> 'fdm-integration',
					'title'			=> __( 'Five-Star Restaurant Menu', 'good-reviews-wp' ),
					'description'	=> __( 'Show reviews for menu items in the lightbox and on individual menu item/permalink pages.', 'good-reviews-wp' ),
					'args'			=> array(
						'label_for' => 'grfwp-settings[fdm-integration]',
						'class' 	=> 'grfwp-fdm-integration'
					)

				)
			);

			$sap->add_setting(
				'grfwp-settings',
				'grfwp-integrations',
				'toggle',
				array(
					'id'			=> 'fdm-submit-review',
					'title'			=> __( 'Five-Star Restaurant Menu Submit Reviews', 'good-reviews-wp' ),
					'description'	=> __( 'Adds a submit review form below the reviews displayed in the lightbox and on individual menu item/permalink pages.', 'good-reviews-wp' ),
					'args'			=> array(
						'label_for' => 'grfwp-settings[fdm-submit-review]',
						'class' 	=> 'grfwp-fdm-submit-review'
					)

				)
			);

			$sap->add_setting(
				'grfwp-settings',
				'grfwp-integrations',
				'toggle',
				array(
					'id'			=> 'rtb-integration',
					'title'			=> __( 'Five-Star Restaurant Reservations', 'good-reviews-wp' ),
					'description'	=> __( 'Show reviews on the reservations page.', 'good-reviews-wp' ),
					'args'			=> array(
						'label_for' => 'grfwp-settings[rtb-integration]',
						'class' 	=> 'grfwp-rtb-integration'
					)

				)
			);

			$sap->add_setting(
				'grfwp-settings',
				'grfwp-integrations',
				'select',
				array(
					'id'           => 'rtb-reviews-position',
					'title'        => __( 'Reviews Position', 'good-reviews-wp' ),
					'description'  => __( 'If enabled, should reviews be displayed above or below the reservations form?.', 'good-reviews-wp' ),
					'blank_option' => false,
					'options'      => array(
						'above'		=> 'Above',
						'below'		=> 'Below'
					),
					'args'			=> array(
						'label_for' => 'rtb-reviews-position',
						'class' 	=> 'grfwp-rtb-reviews-position'
					)
				)
			);

			if ( ! is_object( $grfwp_controller ) or ! $grfwp_controller->permissions->check_permission('styling') ) {
				$styling_permissions = array(
					'disabled'		=> true,
					'disabled_image'=> 'https://www.etoilewebdesign.com/wp-content/uploads/2018/06/Logo-White-Filled40-px.png',
					'purchase_link'	=> 'https://www.fivestarplugins.com/plugins/five-star-restaurant-reviews/'
				);
			}
			else { $styling_permissions = array(); }

			// Create a tab for styling settings
			$sap->add_section(
				'grfwp-settings',
				array(
					'id'			=> 'grfwp-styling-settings-tab',
					'title'			=> __( 'Styling', 'good-reviews-wp' ),
					'is_tab'		=> true
				)
			);

			$sap->add_section(
				'grfwp-settings',
				array_merge(
					array(
						'id'            => 'grfwp-general-styling',
						'title'         => __( 'General', 'good-reviews-wp' ),
						'tab'	          => 'grfwp-styling-settings-tab',
					),
					$styling_permissions
				)
			);

			$sap->add_setting(
				'grfwp-settings',
				'grfwp-general-styling',
				'radio',
				array(
					'id'			=> 'grfwp-styling-layout',
					'title'			=> __( 'Layout', 'good-reviews-wp' ),
					'description'	=> __( 'Choose which layout you want to use for your reviews', 'good-reviews-wp' ),
					'options'		=> array(
						'default'		=> 'Default',
						'thumbnail'		=> 'Thumbnail',
						'image'			=> 'Image',
					)
				)
			);
			$sap->add_setting(
				'grfwp-settings',
				'grfwp-general-styling',
				'toggle',
				array(
					'id'			=> 'grfwp-styling-image-hover',
					'title'			=> __( 'Image Hover', 'good-reviews-wp' ),
					'description'	=> __( 'Enable the hover effect for the Image layout.', 'good-reviews-wp' ),
					'conditional_on'		=> 'grfwp-styling-layout',
					'conditional_on_value'	=> 'image',
				)
			);
			$sap->add_setting(
				'grfwp-settings',
				'grfwp-general-styling',
				'colorpicker',
				array(
					'id'			=> 'grfwp-styling-stars-color',
					'title'			=> __( 'Rating/Stars Color', 'good-reviews-wp' ),
					'description'	=> __( 'Choose the color for the rating numbers and stars that show in reviews.', 'good-reviews-wp' )
				)
			);
			$sap->add_setting(
				'grfwp-settings',
				'grfwp-general-styling',
				'text',
				array(
					'id'			=> 'grfwp-styling-rating-font-size',
					'title'			=> __( 'Rating Font Size', 'good-reviews-wp' ),
					'description'	=> __( 'Choose the font size for the number rating. Include the unit (e.g. 20px or 2em).', 'good-reviews-wp' )
				)
			);
			$sap->add_setting(
				'grfwp-settings',
				'grfwp-general-styling',
				'text',
				array(
					'id'			=> 'grfwp-styling-review-text-font-size',
					'title'			=> __( 'Review Text Font Size', 'good-reviews-wp' ),
					'description'	=> __( 'Choose the font size for the review text. Include the unit (e.g. 20px or 2em).', 'good-reviews-wp' )
				)
			);
			$sap->add_setting(
				'grfwp-settings',
				'grfwp-general-styling',
				'colorpicker',
				array(
					'id'			=> 'grfwp-styling-review-text-color',
					'title'			=> __( 'Review Text Color', 'good-reviews-wp' ),
					'description'	=> __( 'Choose the color for the review text.', 'good-reviews-wp' )
				)
			);
			$sap->add_setting(
				'grfwp-settings',
				'grfwp-general-styling',
				'text',
				array(
					'id'			=> 'grfwp-styling-author-font-size',
					'title'			=> __( 'Author Font Size', 'good-reviews-wp' ),
					'description'	=> __( 'Choose the font size for the author/name of the review. Include the unit (e.g. 20px or 2em).', 'good-reviews-wp' )
				)
			);
			$sap->add_setting(
				'grfwp-settings',
				'grfwp-general-styling',
				'colorpicker',
				array(
					'id'			=> 'grfwp-styling-author-color',
					'title'			=> __( 'Author Color', 'good-reviews-wp' ),
					'description'	=> __( 'Choose the color for the author/name of the review.', 'good-reviews-wp' )
				)
			);
			$sap->add_setting(
				'grfwp-settings',
				'grfwp-general-styling',
				'text',
				array(
					'id'			=> 'grfwp-styling-organization-font-size',
					'title'			=> __( 'Organization Font Size', 'good-reviews-wp' ),
					'description'	=> __( 'Choose the font size for the organization name. Include the unit (e.g. 20px or 2em).', 'good-reviews-wp' )
				)
			);
			$sap->add_setting(
				'grfwp-settings',
				'grfwp-general-styling',
				'colorpicker',
				array(
					'id'			=> 'grfwp-styling-organization-color',
					'title'			=> __( 'Organization Color', 'good-reviews-wp' ),
					'description'	=> __( 'Choose the color for the organization name.', 'good-reviews-wp' )
				)
			);
			$sap->add_setting(
				'grfwp-settings',
				'grfwp-general-styling',
				'colorpicker',
				array(
					'id'			=> 'grfwp-styling-read-more-background-color',
					'title'			=> __( 'Read More Background Color', 'good-reviews-wp' ),
					'description'	=> __( 'Choose the background color for the read more button.', 'good-reviews-wp' )
				)
			);
			$sap->add_setting(
				'grfwp-settings',
				'grfwp-general-styling',
				'colorpicker',
				array(
					'id'			=> 'grfwp-styling-read-more-text-color',
					'title'			=> __( 'Read More Text Color', 'good-reviews-wp' ),
					'description'	=> __( 'Choose the text color for the read more button.', 'good-reviews-wp' )
				)
			);
			$sap->add_setting(
				'grfwp-settings',
				'grfwp-general-styling',
				'colorpicker',
				array(
					'id'			=> 'grfwp-styling-icon-color',
					'title'			=> __( 'Icon Color', 'good-reviews-wp' ),
					'description'	=> __( 'Choose the color of the author, organization and date icons.', 'good-reviews-wp' )
				)
			);
			$sap->add_setting(
				'grfwp-settings',
				'grfwp-general-styling',
				'colorpicker',
				array(
					'id'			=> 'grfwp-styling-show-more-background-color',
					'title'			=> __( 'Show More Background Color', 'good-reviews-wp' ),
					'description'	=> __( 'Choose the background color for the show more button.', 'good-reviews-wp' )
				)
			);
			$sap->add_setting(
				'grfwp-settings',
				'grfwp-general-styling',
				'colorpicker',
				array(
					'id'			=> 'grfwp-styling-show-more-background-hover-color',
					'title'			=> __( 'Show More Background Hover Color', 'good-reviews-wp' ),
					'description'	=> __( 'Choose the background color for the show more button on hover.', 'good-reviews-wp' )
				)
			);
			$sap->add_setting(
				'grfwp-settings',
				'grfwp-general-styling',
				'colorpicker',
				array(
					'id'			=> 'grfwp-styling-show-more-text-color',
					'title'			=> __( 'Show More Text Color', 'good-reviews-wp' ),
					'description'	=> __( 'Choose the text color for the show more button.', 'good-reviews-wp' )
				)
			);
			$sap->add_setting(
				'grfwp-settings',
				'grfwp-general-styling',
				'colorpicker',
				array(
					'id'			=> 'grfwp-styling-show-more-border-color',
					'title'			=> __( 'Show More Border Color', 'good-reviews-wp' ),
					'description'	=> __( 'Choose the border color for the show more button.', 'good-reviews-wp' )
				)
			);


			if( !is_object($grfwp_controller) || !$grfwp_controller->permissions->check_permission('custom_fields') )
			{
				$cf_permissions = [
					'disabled'		=> true,
					'disabled_image'=> 'https://www.etoilewebdesign.com/wp-content/uploads/2018/06/Logo-White-Filled40-px.png',
					'purchase_link'	=> 'https://www.fivestarplugins.com/plugins/five-star-restaurant-reviews/'
				];
			}
			if ( ! is_object( $grfwp_controller ) or ! $grfwp_controller->permissions->check_permission('custom_fields') ) {
				$cf_permissions = array(
					'disabled'		=> true,
					'disabled_image'=> 'https://www.etoilewebdesign.com/wp-content/uploads/2018/06/Logo-White-Filled40-px.png',
					'purchase_link'	=> 'https://www.fivestarplugins.com/plugins/five-star-restaurant-reviews/'
				);
			}
			else { $cf_permissions = array(); }


			// Create a tab for custom fields
			$sap->add_section(
				'grfwp-settings',
				array(
					'id'			=> 'grfwp-cf-settings-tab',
					'title'			=> __( 'Custom Fields', 'good-reviews-wp' ),
					'is_tab'		=> true
				)
			);

			$sap->add_section(
				'grfwp-settings',
				array_merge(
					array(
						'id'            => 'grfwp-cf-options',
						'title'         => __( 'Manage Fields', 'good-reviews-wp' ),
						'tab'	          => 'grfwp-cf-settings-tab',
					),
					$cf_permissions
				)
			);

			$sap->add_setting(
				'grfwp-settings',
				'grfwp-cf-options',
				'toggle',
				array(
					'id'			=> 'grfwp-cf-status',
					'title'			=> __( 'Enable Custom Fields', 'good-reviews-wp' ),
					'description'	=> __( 'Use the table below to add extra custom fields that can be used in your reviews.', 'good-reviews-wp' ),
					'options'		=> array(
						'default'		=> 'Enable?'
					)
				)
			);

			$sap->add_setting(
				'grfwp-settings',
				'grfwp-cf-options',
				'infinite_table',
				array(
					'id'          => 'grfwp-custom-fields',
					'title'       => 'Fields',
					'add_label'   => '&plus; ADD',
					'del_label'   => 'Delete',
					'description' => '',
					'fields'      => array(
						'cf_field_name' => array(
							'type'     => 'text',
							'label'    => 'Field Name',
							'required' => true
						),
						'cf_required'  => array(
							'type'     => 'select',
							'label'    => 'Required',
							'required' => true,
							'options'  => array(
								'true'  => 'Yes',
								'false' => 'No'
							)
						),
						'cf_type'  => array(
							'type'     => 'select',
							'label'    => 'Type',
							'required' => true,
							'options'  => array(
								'text_box'   => 'Text Box',
								'text_area'  => 'Text Area',
								'number'=> 'Number',
								'dropdown'   => 'Dropdown',
								// 'checkbox'   => 'Checkbox',
								// 'radio'      => 'Radio',
								'date'       => 'Date'
							)
						),
						'cf_options'  => array(
							'type'     => 'text',
							'label'    => 'Options',
							'required' => false
						)
					),
					'conditional_on'		=> 'grfwp-cf-status',
					'conditional_on_value'	=> true,
				)
			);


			$sap = apply_filters( 'grfwp_settings_page', $sap );

			$sap->add_admin_menus();
		}

	}
endif;